using System;
using Microsoft.Web.Administration;

namespace Microsoft.Web.Management.Iis.Server
{
    /// <summary>
    /// Serves as a configuration element that can read/write configuration values
    /// for the &lt;centralW3cLogFile&gt; configurationElement.
    /// </summary>
    internal sealed class W3CLogFileElement : BinaryLogFileElement
    {
        /********************************************************************************************
           STATIC FIELDS
         *******************************************************************************************/

        // names of attributes for <centralW3cLogFile> configuration element.
        private const string LogExtFileFlagsAttribute = "logExtFileFlags";

        /********************************************************************************************
           PROPERTIES
         *******************************************************************************************/

        // Properties provide read/write access to configuration.
 
        /// <summary>
        /// Provides access to the log file extension flags for the W3C log format.
        /// </summary>
        public LogExtFileFlags LogExtFileFlags
        {
            get
            {
                return (LogExtFileFlags)base[LogExtFileFlagsAttribute];
            }
            set
            {
                base[LogExtFileFlagsAttribute] = (Int32)value;
            }
        }

    }
}
